# Vk types(deprecated)

**Warning** This library is forked from abandoned project that I've found on github  
the only thing it's useful for is types which **outdated**  
and updated when needed, PR's are welcome!
5.101

## Install

```sh
pip install vk_types
```

## Usage

Simple example
```python
pass

```

## Authors

👤 **[prostomarkeloff](https://github.com/prostomarkeloff)**  
👤 **[kz159](https://github.com/kz159)**